@@ -335,6 +335,12 @@ sub install_accessors{
         $attribute->create($metaclass, $attribute->name, %{$attribute});
     }
 
+    if(!$attribute->{associated_methods} && ($attribute->{is} || '') ne 'bare'){
+        Carp::cluck(
+            'Attribute (' . $attribute->name . ') of class ' . $metaclass->name
+            . ' has no associated methods (did you mean to provide an "is" argument?)');
+    }
+
     return;
 }
 
@@ -375,10 +381,7 @@ sub _make_delegation_method {
     my $delegator = $self->delegation_metaclass;
     Mouse::Util::load_class($delegator);
 
-    return $delegator->_generate_delegation($self, $handle,
-        ref($method_to_call) eq 'ARRAY'
-            ? @{$method_to_call}
-            :   $method_to_call);
+    return $delegator->_generate_delegation($self, $handle, $method_to_call);
 }
 
 sub throw_error{
@@ -397,7 +400,7 @@ Mouse::Meta::Attribute - The Mouse attribute metaclass
 
 =head1 VERSION
 
-This document describes Mouse version 0.50_02
+This document describes Mouse version 0.50_03
 
 =head1 METHODS
 
