@@ -2,7 +2,7 @@ package Mouse::Spec;
 use strict;
 use warnings;
 
-our $VERSION = '0.50_02';
+our $VERSION = '0.50_03';
 
 our $MouseVersion = $VERSION;
 our $MooseVersion = '0.93';
@@ -19,7 +19,7 @@ Mouse::Spec - To what extent Mouse is compatible with Moose
 
 =head1 VERSION
 
-This document describes Mouse version 0.50_02
+This document describes Mouse version 0.50_03
 
 =head1 SYNOPSIS
 
@@ -41,7 +41,7 @@ The sugary API is highly compatible with Moose.
 
 =head3 Meta object protocols
 
-Any MOP in Mouse has no attributes.
+Any MOP in Mouse has no attributes by default.
 
 For this reason, C<< $metaclass->meta->make_immutable() >> does not yet work as you expect.
 B<Don not make metaclasses immutable>.
@@ -59,6 +59,14 @@ Role exclusion, C<exclude()>, is not implemented.
 C<< use Mouse -metaclass => ... >> are not implemented.
 Use C<< use Mouse -traits => ... >> instead.
 
+=head3 Mouse::Meta::Attribute::Native
+
+Native traits are not supported directly, but C<MouseX::NativeTraits> is
+available on CPAN. Once you have installed it, you can use it as the same way
+in Moose. That is, native traits are automatically loaded by Mouse.
+
+See L<MouseX::NativeTraits> for details.
+
 =head2 Notes about Moose::Cookbook
 
 Many recipes in L<Moose::Cookbook> fit L<Mouse>, including:
